<p align="center">
    <h1 align="center">
        Phase2 CLI 👨‍💻
    </h1>
    <p align="center">All-in-one command line tool for interfacing with Groth16 zkSNARKs Phase 2 Trusted Setup ceremonies</p>
</p>

<p align="center">
    <a href="https://github.com/privacy-scaling-explorations/p0tion">
        <img src="https://img.shields.io/badge/project-p0tion-blue.svg?style=flat-square">
    </a>
    <a href="https://github.com/privacy-scaling-explorations/p0tion/blob/main/LICENSE">
        <img alt="Github License" src="https://img.shields.io/github/license/privacy-scaling-explorations/p0tion.svg?style=flat-square">
    </a>
    <a href="https://www.npmjs.com/package/@p0tion/phase2cli">
        <img alt="NPM Version" src="https://img.shields.io/npm/v/@p0tion/phase2cli?style=flat-square" />
    </a>
    <a href="https://npmjs.org/package/@p0tion/phase2cli">
        <img alt="Downloads" src="https://img.shields.io/npm/dm/@p0tion/phase2cli.svg?style=flat-square" />
    </a>
    <a href="https://eslint.org/">
        <img alt="Linter" src="https://img.shields.io/badge/linter-eslint-8080f2?style=flat-square&logo=eslint" />
    </a>
    <a href="https://prettier.io/">
        <img alt="Prettier" src="https://img.shields.io/badge/code%20style-prettier-f8bc45?style=flat-square&logo=prettier" />
    </a>
</p>

<div align="center">
    <h4>
        <a href="https://github.com/privacy-scaling-explorations/p0tion/blob/main/CONTRIBUTING.md">
            👥 Contributing
        </a>
        <span>&nbsp;&nbsp;|&nbsp;&nbsp;</span>
        <a href="https://github.com/privacy-scaling-explorations/p0tion/blob/main/CODE_OF_CONDUCT.md">
            🤝 Code of conduct
        </a>
        <span>&nbsp;&nbsp;|&nbsp;&nbsp;</span>
        <a href="https://discord.gg/sF5CT5rzrR">
            🗣️ Chat &amp; Support
        </a>
    </h4>
</div>

| The interaction with Trusted Setup ceremonies commonly involves the usage of different tools according to the roles (coordinator vs. participants) and ceremony stages (setup, contribution, finalization). The Phase2 CLI acts as an all-in-one independent interface with a custom set of user-friendly and interactive commands. |
| ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |

Rounding up the option of using a unique tool for different ceremony stages makes it possible to reduce the context switch, level of expertise, and bug exposure. This standard tool (built on top of the `actions` package) contains only the core commands for interfacing with one or more Trusted Setup Phase 2 ceremonies. You could get advantage from these commands and customize (or extend them) based on your unique ceremony needs. By using the CLI, the computing power of the contributor's machine could be fully exploited thus enabling contributions up to larger sizes than with ordinary web-browser clients.

## 🛠 Installation

Install the `@p0tion/phase2cli` package globally

```bash
npm i -g @p0tion/phase2cli
```

or run specific commands with `npx`:

```bash
npx @p0tion/phase2cli contribute
```

> Please note that phase2cli only runs on Linux or Mac systems. If a Windows user, please install [WSL2](https://learn.microsoft.com/en-us/windows/wsl/install) first.

## 📜 Usage

### Local Development

**Prerequisities**

-   Node.js version 16.0 or higher.
-   Yarn version 3.5.0 or higher.

Copy the `.env.default` file as `.env`:

```bash
cp .env.default .env
```

And add your environment variables.

⚠️ Your environment variables must match the corresponding properties values inside the `.env` file of the `actions` package ⚠️

#### Core Commands

```bash
Usage: phase2cli [options] [command]

All-in-one command line tool for interfacing with Groth16 zkSNARKs Phase 2 Trusted Setup ceremonies

Options:
  -V, --version   output the version number
  -h, --help      display help for command

Commands:
  auth            authenticate yourself using your Github Account (Device Flow OAuth 2.0)
  contribute      compute contributions for a Phase2 Trusted Setup ceremony circuits
  clean           clean up output generated by commands from the current working directory
  logout          sign out from Firebae Auth service and delete Github OAuth 2.0 token from your machine
  coordinate      special subset of commands for coordinating a ceremony (coordinator only)
  help [command]  display help for command
```

#### Coordinator Commands

```bash
Usage: phase2cli coordinate [options] [command]

special subset of commands for coordinating a ceremony (coordinator only)

Options:
  -h, --help      display help for command

Commands:
  setup           setup a Groth16 Phase 2 Trusted Setup ceremony for zk-SNARK circuits
  observe         real-time updates about queue status for each ceremony circuit
  finalize        finalize a Phase2 Trusted Setup ceremony (beacon + artifacts exports)
  help [command]  display help for command
```
